@@ -706,63 +706,7 @@ class CLIP_OT_setup_tracking_scene(Operator):
             "indirect_only",
         )
 
-    @staticmethod
-    def _wipeDefaultNodes(tree):
-        if len(tree.nodes) != 4:
-            return False
-        types = [node.type for node in tree.nodes]
-        types.sort()
-
-        if (types[0] == 'COMPOSITE' and types[1] == 'REROUTE'
-                and types[2] == 'R_LAYERS' and types[3] == 'VIEWER'):
-            while tree.nodes:
-                tree.nodes.remove(tree.nodes[0])
-
-    @staticmethod
-    def _findNode(tree, type):
-        for node in tree.nodes:
-            if node.type == type:
-                return node
-
-        return None
-
-    @staticmethod
-    def _findOrCreateNode(tree, type):
-        node = CLIP_OT_setup_tracking_scene._findNode(tree, type)
-
-        if not node:
-            node = tree.nodes.new(type=type)
-
-        return node
-
-    @staticmethod
-    def _needSetupNodes(context):
-        scene = context.scene
-        tree = scene.node_tree
-
-        if not tree:
-            # No compositor node tree found, time to create it!
-            return True
-
-        for node in tree.nodes:
-            if node.type in {'MOVIECLIP', 'MOVIEDISTORTION'}:
-                return False
-
-        return True
-
-    @staticmethod
-    def _offsetNodes(tree):
-        for a in tree.nodes:
-            for b in tree.nodes:
-                if a != b and a.location == b.location:
-                    b.location += Vector((40.0, 20.0))
-
     def _setupNodes(self, context):
-        if not self._needSetupNodes(context):
-            # Compositor nodes were already setup or even changes already
-            # do nothing to prevent nodes damage.
-            return
-
         # Enable backdrop for all compositor spaces.
         def setup_space(space):
             space.show_backdrop = True
@@ -771,20 +715,24 @@ class CLIP_OT_setup_tracking_scene(Operator):
 
         sc = context.space_data
         scene = context.scene
-        scene.use_nodes = True
-        tree = scene.node_tree
+        tree = scene.compositing_node_group
         clip = sc.clip
 
         need_stabilization = False
 
-        # Remove all the nodes if they came from default node setup.
-        # This is simplest way to make it so final node setup is correct.
-        self._wipeDefaultNodes(tree)
+        # If a compositing node tree exists already, preserve it and create
+        # a separate one for the tracking setup.
+        if tree:
+            tree.use_fake_user = True
+
+        tree = bpy.data.node_groups.new("Tracking Setup", "CompositorNodeTree")
+        scene.compositing_node_group = tree
 
         # Create nodes.
-        rlayer_fg = self._findOrCreateNode(tree, 'CompositorNodeRLayers')
+        rlayer_fg = tree.nodes.new(type='CompositorNodeRLayers')
         rlayer_bg = tree.nodes.new(type='CompositorNodeRLayers')
-        composite = self._findOrCreateNode(tree, 'CompositorNodeComposite')
+        output = tree.nodes.new(type='NodeGroupOutput')
+        tree.interface.new_socket(name="Image", in_out='OUTPUT', socket_type="NodeSocketColor")
 
         movieclip = tree.nodes.new(type='CompositorNodeMovieClip')
         distortion = tree.nodes.new(type='CompositorNodeMovieDistortion')
@@ -801,12 +749,12 @@ class CLIP_OT_setup_tracking_scene(Operator):
         movieclip.clip = clip
 
         distortion.clip = clip
-        distortion.distortion_type = 'UNDISTORT'
+        distortion.inputs['Type'].default_value = 'Undistort'
 
         if need_stabilization:
             stabilize.clip = clip
 
-        scale.space = 'RENDER_SIZE'
+        scale.inputs['Type'].default_value = 'Render Size'
 
         rlayer_bg.scene = scene
         rlayer_bg.layer = "Background"
@@ -823,15 +771,15 @@ class CLIP_OT_setup_tracking_scene(Operator):
         else:
             tree.links.new(distortion.outputs["Image"], scale.inputs["Image"])
 
-        tree.links.new(scale.outputs["Image"], shadowcatcher.inputs[1])
+        tree.links.new(scale.outputs["Image"], shadowcatcher.inputs["Background"])
 
-        tree.links.new(rlayer_bg.outputs["Image"], shadowcatcher.inputs[2])
+        tree.links.new(rlayer_bg.outputs["Image"], shadowcatcher.inputs["Foreground"])
 
-        tree.links.new(rlayer_fg.outputs["Image"], alphaover.inputs[2])
+        tree.links.new(rlayer_fg.outputs["Image"], alphaover.inputs["Foreground"])
 
-        tree.links.new(shadowcatcher.outputs["Image"], alphaover.inputs[1])
+        tree.links.new(shadowcatcher.outputs["Image"], alphaover.inputs["Background"])
 
-        tree.links.new(alphaover.outputs["Image"], composite.inputs["Image"])
+        tree.links.new(alphaover.outputs["Image"], output.inputs["Image"])
         tree.links.new(alphaover.outputs["Image"], viewer.inputs["Image"])
 
         # Place nodes.
@@ -862,14 +810,11 @@ class CLIP_OT_setup_tracking_scene(Operator):
         alphaover.location = shadowcatcher.location
         alphaover.location += Vector((250.0, -250.0))
 
-        composite.location = alphaover.location
-        composite.location += Vector((300.0, -100.0))
+        output.location = alphaover.location
+        output.location += Vector((300.0, -100.0))
 
-        viewer.location = composite.location
-        composite.location += Vector((0.0, 200.0))
-
-        # Ensure no nodes were created on the position of existing node.
-        self._offsetNodes(tree)
+        viewer.location = output.location
+        output.location += Vector((0.0, 200.0))
 
     @staticmethod
     def _createMesh(collection, name, vertices, faces):
