@@ -165,7 +165,7 @@ class AddPresetBase:
                 print("Writing Preset: {!r}".format(filepath))
 
                 if is_xml:
-                    import rna_xml
+                    import _rna_xml as rna_xml
                     rna_xml.xml_file_write(context, filepath, preset_menu_class.preset_xml_map)
                 else:
 
@@ -302,10 +302,10 @@ class ExecutePreset(Operator):
             try:
                 bpy.utils.execfile(filepath)
             except Exception as ex:
-                self.report({'ERROR'}, "Failed to execute the preset: " + repr(ex))
+                self.report({'ERROR'}, rpt_("Failed to execute the preset: {:s}").format(repr(ex)))
 
         elif ext == ".xml":
-            import rna_xml
+            import _rna_xml as rna_xml
             preset_xml_map = preset_class.preset_xml_map
             preset_xml_secure_types = getattr(preset_class, "preset_xml_secure_types", None)
 
@@ -584,7 +584,7 @@ class AddPresetEEVEERaytracing(AddPresetBase, Operator):
     """Add or remove an EEVEE ray-tracing preset"""
     bl_idname = "render.eevee_raytracing_preset_add"
     bl_label = "Add Raytracing Preset"
-    preset_menu = "RENDER_PT_eevee_next_raytracing_presets"
+    preset_menu = "RENDER_PT_eevee_raytracing_presets"
 
     preset_defines = [
         "eevee = bpy.context.scene.eevee",
@@ -709,7 +709,7 @@ class SavePresetInterfaceTheme(AddPresetBase, Operator):
     # while redrawing as it may involve remote file-system access.
 
     def execute(self, context):
-        import rna_xml
+        import _rna_xml as rna_xml
         filepath = context.preferences.themes[0].filepath
         if (not filepath) or _is_path_readonly(filepath):
             self.report({'ERROR'}, "Built-in themes cannot be overwritten")
@@ -719,7 +719,7 @@ class SavePresetInterfaceTheme(AddPresetBase, Operator):
         try:
             rna_xml.xml_file_write(context, filepath, preset_menu_class.preset_xml_map)
         except Exception as ex:
-            self.report({'ERROR'}, "Unable to overwrite preset: {:s}".format(str(ex)))
+            self.report({'ERROR'}, rpt_("Unable to overwrite preset: {:s}").format(str(ex)))
             import traceback
             traceback.print_exc()
             return {'CANCELLED'}
@@ -933,8 +933,6 @@ class WM_OT_operator_presets_cleanup(Operator):
             operators = [
                 "WM_OT_alembic_export",
                 "WM_OT_alembic_import",
-                "WM_OT_collada_export",
-                "WM_OT_collada_import",
                 "WM_OT_obj_export",
                 "WM_OT_obj_import",
                 "WM_OT_ply_export",
@@ -958,7 +956,7 @@ class WM_OT_operator_presets_cleanup(Operator):
 
 
 class AddPresetGpencilBrush(AddPresetBase, Operator):
-    """Add or remove grease pencil brush preset"""
+    """Add or remove Grease Pencil brush preset"""
     bl_idname = "scene.gpencil_brush_preset_add"
     bl_label = "Add Grease Pencil Brush Preset"
     preset_menu = "VIEW3D_PT_gpencil_brush_presets"
